<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/core/RUnit.cpp" line="+273"/>
        <source>None</source>
        <translation>Brak</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Inch</source>
        <translation>Cal</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Foot</source>
        <translation>Stopa</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Mile</source>
        <translation>Mila</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Millimeter</source>
        <translation>Milimetr</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Centimeter</source>
        <translation>Centrymetr</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Meter</source>
        <translation>Metr</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Kilometer</source>
        <translation>Kilometr</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Microinch</source>
        <translation>Mikrocal</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Mil</source>
        <translation>Mil</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Yard</source>
        <translation>Jard</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Angstrom</source>
        <translation>Angstrom</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Nanometer</source>
        <translation>Nanometr</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Micron</source>
        <translation>Mikron</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Decimeter</source>
        <translation>Decymetr</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Decameter</source>
        <translation>Dekametr</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Hectometer</source>
        <translation>Hektometr</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Gigameter</source>
        <translation>Gigametr</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Astro</source>
        <translation>Astro</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Lightyear</source>
        <translation>Rok świetlny</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Parsec</source>
        <translation>Parsek</translation>
    </message>
</context>
<context>
    <name>RColor</name>
    <message>
        <location filename="../src/core/RColor.cpp" line="+287"/>
        <source>By Layer</source>
        <translation>Według warstwy</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>By Block</source>
        <translation>Według bloku</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Red</source>
        <translation>Czerwony</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Yellow</source>
        <translation>Żółty</translation>
    </message>
    <message>
        <location line="-4"/>
        <source>Green</source>
        <translation>Zielony</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Cyan</source>
        <translation>Cyjanowy</translation>
    </message>
    <message>
        <location line="-1"/>
        <source>Blue</source>
        <translation>Niebieski</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Magenta</source>
        <translation>Magenta</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Orange</source>
        <translation>Pomarańczowy</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dark Red</source>
        <translation>Ciemny czerwony</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dark Green</source>
        <translation>Ciemny zielony</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dark Blue</source>
        <translation>Granatowy</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dark Cyan</source>
        <translation>Ciemny niebieski</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dark Magenta</source>
        <translation>Ciemny purpurowy</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dark Yellow</source>
        <translation>Ciemny żółty</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Black</source>
        <translation>Czarny</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>White</source>
        <translation>Biały</translation>
    </message>
    <message>
        <location line="-2"/>
        <source>Gray</source>
        <translation>Szary</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Light Gray</source>
        <translation>Jasny szary</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Others...</source>
        <translation>Inne...</translation>
    </message>
</context>
<context>
    <name>RDocumentVariables</name>
    <message>
        <location filename="../src/core/RDocumentVariables.cpp" line="+45"/>
        <source>Current Layer ID</source>
        <translation>Aktywna warstwa</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Drawing Unit</source>
        <translation>Jednostka rysunku</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Linetype Scale</source>
        <translation>Skala rodzaju linii</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dimension Font</source>
        <translation>Czcionka wymiaru</translation>
    </message>
</context>
<context>
    <name>REntity</name>
    <message>
        <source>Referenced Block</source>
        <translation type="obsolete">Blok</translation>
    </message>
    <message>
        <location filename="../src/core/RBlockReferenceEntity.cpp" line="+93"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/core/RViewportEntity.cpp" line="+73"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Position</source>
        <translation>Położenie</translation>
    </message>
    <message>
        <location filename="../src/core/RBlock.cpp" line="+65"/>
        <source>Pixel Unit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RBlockReferenceEntity.cpp" line="-2"/>
        <location line="+3"/>
        <location filename="../src/core/RLayout.cpp" line="+82"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/core/RTextBasedEntity.cpp" line="+72"/>
        <location filename="../src/core/RViewportEntity.cpp" line="-2"/>
        <location line="+8"/>
        <location line="+2"/>
        <source>X</source>
        <translation>X</translation>
    </message>
    <message>
        <location line="+0"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Origin</source>
        <translation>Początek układu współrzędnych</translation>
    </message>
    <message>
        <location line="-1"/>
        <location filename="../src/core/RBlockReferenceEntity.cpp" line="-2"/>
        <location line="+3"/>
        <location filename="../src/core/RLayout.cpp" line="-11"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/core/RTextBasedEntity.cpp" line="+1"/>
        <location filename="../src/core/RViewportEntity.cpp" line="-9"/>
        <location line="+8"/>
        <location line="+2"/>
        <source>Y</source>
        <translation>Y</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RBlockReferenceEntity.cpp" line="-2"/>
        <location line="+3"/>
        <location filename="../src/core/RLayout.cpp" line="-11"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/core/RTextBasedEntity.cpp" line="+1"/>
        <location filename="../src/core/RViewportEntity.cpp" line="-9"/>
        <location line="+10"/>
        <source>Z</source>
        <translation>Z</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Layout</source>
        <translation>Układ</translation>
    </message>
    <message>
        <location filename="../src/core/RBlockReferenceEntity.cpp" line="-2"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/core/RViewportEntity.cpp" line="-7"/>
        <source>Scale</source>
        <translation>Skala</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Angle</source>
        <translation>Kąt</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Columns</source>
        <translation>Liczba kolumn</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Rows</source>
        <translation>Liczba wierszy</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Column Spacing</source>
        <translation>Odstępy kolumn</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Row Spacing</source>
        <translation>Odstępy wierszy</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Attributes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/core/REntity.cpp" line="+87"/>
        <location filename="../src/core/RObject.cpp" line="+66"/>
        <source>Type</source>
        <translation>Rodzaj</translation>
    </message>
    <message>
        <location filename="../src/core/RBlockReferenceEntity.cpp" line="-14"/>
        <source>Block</source>
        <translation>Blok</translation>
    </message>
    <message>
        <location filename="../src/core/REntity.cpp" line="+1"/>
        <source>Block ID</source>
        <translation>Identyfikator bloku</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Layer</source>
        <translation>Warstwa</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RLayer.cpp" line="+99"/>
        <source>Linetype</source>
        <translation>Rodzaj linii</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Linetype Scale</source>
        <translation>Skala rodzaju linii</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RLayer.cpp" line="+1"/>
        <source>Lineweight</source>
        <translation>Szerokość linii</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RLayer.cpp" line="-2"/>
        <source>Color</source>
        <translation>Kolor</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Displayed Color</source>
        <translation>Wyświetlany kolor</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Draw Order</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Kolejność rysowania</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Boundary</source>
        <translation>Granica</translation>
    </message>
    <message>
        <location line="-3"/>
        <location filename="../src/core/RLayout.cpp" line="+3"/>
        <source>Left</source>
        <translation>Lewo</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RLayout.cpp" line="+1"/>
        <source>Bottom</source>
        <translation>Dół</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RLayout.cpp" line="+1"/>
        <source>Right</source>
        <translation>Prawo</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RLayout.cpp" line="+1"/>
        <source>Top</source>
        <translation>Góra</translation>
    </message>
    <message>
        <location filename="../src/core/RObject.cpp" line="-1"/>
        <location filename="../src/core/RPropertyTypeId.cpp" line="+108"/>
        <source>Custom</source>
        <translation>Dostosowany</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Handle</source>
        <translation>Uchwyt</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Protected</source>
        <translation>Zabezpieczony</translation>
    </message>
    <message>
        <location filename="../src/core/REntity.cpp" line="+2"/>
        <location filename="../src/core/RLayout.cpp" line="+1"/>
        <location filename="../src/core/RViewportEntity.cpp" line="-2"/>
        <source>Width</source>
        <translation>Szerokość</translation>
    </message>
    <message>
        <location line="+0"/>
        <location line="+1"/>
        <source>Size</source>
        <translation>Rozmiar</translation>
    </message>
    <message>
        <location line="+0"/>
        <location filename="../src/core/RLayout.cpp" line="+1"/>
        <location filename="../src/core/RViewportEntity.cpp" line="+1"/>
        <source>Height</source>
        <translation>Wysokość</translation>
    </message>
    <message>
        <location filename="../src/core/RTextBasedEntity.cpp" line="-3"/>
        <source>Simple</source>
        <translation>Zwykły</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Text Position</source>
        <translation>Położenie tekstu</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Text</source>
        <translation>Tekst</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Plain Text</source>
        <translation>Zwykły tekst</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Font Name</source>
        <translation>Nazwa czcionki</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Text Height</source>
        <translation>Wysokość tekstu</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Text Angle</source>
        <translation>Kąt tekstu</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>X Scale</source>
        <translation>Skala X</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Bold</source>
        <translation>Pogrubienie</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Italic</source>
        <translation>Kursywa</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Line Spacing</source>
        <translation>Odstępy między wierszami</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <source>Alignment</source>
        <translation>Wyrównanie</translation>
    </message>
    <message>
        <location line="-1"/>
        <source>Horizontal</source>
        <translation>Poziomo</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Vertical</source>
        <translation>Pionowo</translation>
    </message>
    <message>
        <location filename="../src/core/RViewportEntity.cpp" line="+2"/>
        <source>Rotation</source>
        <translation>Obrót</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>On</source>
        <translation type="unfinished">Włączona</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <source>View Center</source>
        <translation>Wyświetl środek</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>View Target</source>
        <translation>Wyświetl cel</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Overall</source>
        <translation type="unfinished">Ogólnie</translation>
    </message>
    <message>
        <location filename="../src/core/RBlock.cpp" line="-6"/>
        <location filename="../src/core/RLayer.cpp" line="-8"/>
        <location filename="../src/core/RLayout.cpp" line="-24"/>
        <source>Name</source>
        <translation>Nazwa</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Hidden</source>
        <translation>Ukryta</translation>
    </message>
    <message>
        <location filename="../src/core/RLayer.cpp" line="+1"/>
        <source>Off</source>
        <translation>Wyłączona</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Frozen</source>
        <translation>Zamrożona</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Locked</source>
        <translation>Zablokowana</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Collapsed</source>
        <translation>Zwinięta</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Plottable</source>
        <translation>Drukowana</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Snappable</source>
        <translation>Przyciągająca</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Off is Freeze</source>
        <translation type="unfinished">Wyłączenie działa jak zamrożenie</translation>
    </message>
    <message>
        <location filename="../src/core/RLayout.cpp" line="+1"/>
        <source>Tab Order</source>
        <translation>Kolejność kart</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Min Limits</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Max Limits</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Insertion Base</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Min Extents</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Max Extents</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/core/RBlockReferenceData.cpp" line="+627"/>
        <source>Circular (recursive) block referencing detected:</source>
        <translation>Wykryto rekursywne zależności bloku:</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Block name:</source>
        <translation>Nazwa bloku:</translation>
    </message>
</context>
<context>
    <name>RGuiAction</name>
    <message>
        <location filename="../src/core/RGuiAction.cpp" line="+184"/>
        <source>Requires selection</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Wymaga zaznaczenia</translation>
    </message>
</context>
<context>
    <name>RLayer</name>
    <message>
        <source>Name</source>
        <translation type="vanished">Nazwa</translation>
    </message>
    <message>
        <source>Frozen</source>
        <translation type="obsolete">Zamrożony</translation>
    </message>
    <message>
        <source>Locked</source>
        <translation type="vanished">Zablokowany</translation>
    </message>
    <message>
        <source>Color</source>
        <translation type="vanished">Kolor</translation>
    </message>
    <message>
        <source>Linetype</source>
        <translation type="vanished">Rodzaj linii</translation>
    </message>
    <message>
        <source>Lineweight</source>
        <translation type="vanished">Szerokość linii</translation>
    </message>
</context>
<context>
    <name>RLinetype</name>
    <message>
        <source>By Layer</source>
        <translation type="vanished">Według warstwy</translation>
    </message>
    <message>
        <source>By Block</source>
        <translation type="vanished">Według bloku</translation>
    </message>
    <message>
        <source>Continuous</source>
        <translation type="vanished">Ciągła</translation>
    </message>
    <message>
        <source>Dot</source>
        <translation type="vanished">Wielopunktowa</translation>
    </message>
    <message>
        <source>Dot (small)</source>
        <translation type="vanished">Wielopunktowa (mała)</translation>
    </message>
    <message>
        <source>Dot (large)</source>
        <translation type="vanished">Wielopunktowa (wielka)</translation>
    </message>
    <message>
        <source>Dash</source>
        <translation type="vanished">Kreskowa</translation>
    </message>
    <message>
        <source>Dash (small)</source>
        <translation type="vanished">Kreskowa (mała)</translation>
    </message>
    <message>
        <source>Dash (large)</source>
        <translation type="vanished">Kreskowa (wielka)</translation>
    </message>
    <message>
        <source>Dash Dot</source>
        <translation type="vanished">Punktowa</translation>
    </message>
    <message>
        <source>Dash Dot (small)</source>
        <translation type="vanished">Punktowa (mała)</translation>
    </message>
    <message>
        <source>Dash Dot (large)</source>
        <translation type="vanished">Punktowa (wielka)</translation>
    </message>
    <message>
        <source>Divide</source>
        <translation type="vanished">Dwupunktowa</translation>
    </message>
    <message>
        <source>Divide (small)</source>
        <translation type="vanished">Dwupunktowa (mała)</translation>
    </message>
    <message>
        <source>Divide (large)</source>
        <translation type="vanished">Dwupunktowa (wielka)</translation>
    </message>
    <message>
        <source>Center</source>
        <translation type="vanished">Środkowa</translation>
    </message>
    <message>
        <source>Center (small)</source>
        <translation type="vanished">Środkowa (mała)</translation>
    </message>
    <message>
        <source>Center (large)</source>
        <translation type="vanished">Środkowa (wielka)</translation>
    </message>
    <message>
        <source>Border</source>
        <translation type="vanished">Obramowanie</translation>
    </message>
    <message>
        <source>Border (small)</source>
        <translation type="vanished">Obramowanie (mała)</translation>
    </message>
    <message>
        <source>Border (large)</source>
        <translation type="vanished">Obramowanie (wielka)</translation>
    </message>
    <message>
        <location filename="../src/core/RLinetype.cpp" line="+48"/>
        <source>Name</source>
        <translation>Nazwa</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Description</source>
        <translation>Opis</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Metric</source>
        <translation>Metryczny</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Pattern</source>
        <translation>Wzór</translation>
    </message>
</context>
<context>
    <name>RLinetypePattern</name>
    <message>
        <location filename="../src/core/RLinetypePattern.cpp" line="+856"/>
        <source>By Layer</source>
        <translation>Według warstwy</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>By Block</source>
        <translation>Według bloku</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Continuous</source>
        <translation>Ciągła</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Border</source>
        <translation>Obramowanie</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Center</source>
        <translation>Środkowa</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Dash dot</source>
        <translation>Kreskowo-kropkowa</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Dashed</source>
        <translation>Kreskowa</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Divide</source>
        <translation>Dwupunktowa</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Dot</source>
        <translation>Kropkowa</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Hidden</source>
        <translation>Ukryta</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Phantom</source>
        <translation>Zarys</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>ISO dash</source>
        <translation>ISO kreskowa</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO dash space</source>
        <translation>ISO kreskowa z odstępami</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO long-dash dot</source>
        <translation>ISO z długą kreską i kropką</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO long-dash double-dot</source>
        <translation>ISO z długą kreską i dwiema kropkami</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO long-dash triple-dot</source>
        <translation>ISO z długą kreską i trzema kropkami</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO dot</source>
        <translation>ISO kropkowa</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO long-dash short-dash</source>
        <translation>ISO z długą i krótką kreską</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO long-dash double-short-dash</source>
        <translation>ISO z długą kreską i dwoma krótkimi kreskami</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO dash dot</source>
        <translation>ISO kreskowo-kropkowa</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO double-dash dot</source>
        <translation>ISO z dwiema kreskami i kropką</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO dash double-dot</source>
        <translation>ISO kreskowa z dwiema kropkami</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO double-dash double-dot</source>
        <translation>ISO z dwiema kreskami i dwiema kropkami</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO dash triple-dot</source>
        <translation>ISO z kreską i trzema kropkami</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO double-dash triple-dot</source>
        <translation>ISO z dwiema kreskami i trzema kropkami</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Hot Water Supply</source>
        <translation>Instalacja ciepłej wody</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Hot Water</source>
        <translation>Ciepła woda</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Gas Line</source>
        <translation>Instalacja gazowa</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Batting</source>
        <translation>Gradzinowanie</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Zig Zag</source>
        <translation>Zygzakowata</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Tracks</source>
        <translation>Ścieżki</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Fenceline 1</source>
        <translation>Ogrodzenie 1</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Fenceline 2</source>
        <translation>Ogrodzenie 2</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Drainage</source>
        <translation>Odpływ</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Drainage Reversed</source>
        <translation>Odpływ w przeciwną stronę</translation>
    </message>
</context>
<context>
    <name>RLineweight</name>
    <message>
        <location filename="../src/core/RLineweight.cpp" line="+35"/>
        <source>By Layer</source>
        <translation>Według warstwy</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>By Block</source>
        <translation>Według bloku</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Default</source>
        <translation>Domyślne</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.00mm</source>
        <translation>0,00 mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.05mm</source>
        <translation>0,00 mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.09mm</source>
        <translation>0,09 mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.13mm (ISO)</source>
        <translation>0,13 mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.15mm</source>
        <translation>0,15 mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.18mm (ISO)</source>
        <translation>0,18 mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.20mm</source>
        <translation>0,20 mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.25mm (ISO)</source>
        <translation>0,25 mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.30mm</source>
        <translation>0,30 mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.35mm (ISO)</source>
        <translation>0,35 mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.40mm</source>
        <translation>0,40 mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.50mm (ISO)</source>
        <translation>0,50 mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.53mm</source>
        <translation>0,53 mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.60mm</source>
        <translation>0,60 mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.70mm (ISO)</source>
        <translation>0,70 mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.80mm</source>
        <translation>0,80 mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.90mm</source>
        <translation>0,90 mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>1.00mm (ISO)</source>
        <translation>1,00 mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>1.06mm</source>
        <translation>1,06 mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>1.20mm</source>
        <translation>1,20 mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>1.40mm (ISO)</source>
        <translation>1,40 mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>1.58mm</source>
        <translation>1,58 mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>2.00mm (ISO)</source>
        <translation>2,00 mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>2.11mm</source>
        <translation>2,11 mm</translation>
    </message>
</context>
<context>
    <name>RObject</name>
    <message>
        <source>Custom</source>
        <translation type="vanished">Dostosowany</translation>
    </message>
    <message>
        <source>Type</source>
        <translation type="obsolete">Typ</translation>
    </message>
    <message>
        <source>Handle</source>
        <translation type="vanished">Uchwyt</translation>
    </message>
</context>
</TS>
